@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
+ * Foundation, Inc.,  51 Franklin Street, Fifth Floor, Cambridge, MA 02139, USA.
  */
 /*
   @NOTATION@
@@ -26,16 +26,13 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-
 #include <string.h>
+
 #include <glib.h>
 #include <glib/gstdio.h>
-
 #include <glib/gi18n-lib.h>
 
-#include "gnome-program.h"
 #include "gnome-url.h"
-
 #include "gnome-help.h"
 
 static char *
@@ -149,7 +146,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 
 	if (doc_id == NULL) {
 		g_object_get (program, GNOME_PARAM_APP_ID, &doc_id, NULL);
-		free_doc_id = doc_id;
+		free_doc_id = (char *)doc_id;
 	}
 
 	if (doc_id == NULL)
