@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 /*
   @NOTATION@
@@ -53,6 +53,8 @@
 #include <fcntl.h>
 #include <io.h>
 
+#define pipe(fds) _pipe(fds, 4096, _O_BINARY)
+
 /* Microsoft's strtok() *is* thread-safe, it uses a thread-local
  * buffer. "Use" the third argument to this macro so gcc doesn't
  * complain about an unused variable, and we don't have to ifdef out
